.. _sec-particle_layer:

Particle layer
==============

Particle layers are 1D non-uniform participating media consisting of particles.
Particle layer scene elements are created using :class:`.ParticleLayer`.
